@@ -121,7 +121,7 @@ setMethod("norm", signature(x = "dgeMatrix", type = "missing"),
 
 setMethod("norm", signature(x = "dgeMatrix", type = "character"),
 	  function(x, type, ...)
-	  .Call("dgeMatrix_norm", x, type),
+	  .Call("dgeMatrix_norm", x, type, PACKAGE = "Matrix"),
 	  valueClass = "numeric")
 
 setMethod("rcond", signature(x = "dgeMatrix", type = "missing"),
@@ -129,35 +129,35 @@ setMethod("rcond", signature(x = "dgeMatrix", type = "missing"),
 
 setMethod("rcond", signature(x = "dgeMatrix", type = "character"),
 	  function(x, type, ...)
-	  .Call("dgeMatrix_rcond", x, type),
+	  .Call("dgeMatrix_rcond", x, type, PACKAGE = "Matrix"),
 	  valueClass = "numeric")
 
 setMethod("t", signature(x = "dgeMatrix"), t_geMatrix)
 
 setMethod("crossprod", signature(x = "dgeMatrix", y = "missing"),
-	  function(x, y = NULL) .Call("dgeMatrix_crossprod", x, FALSE),
+	  function(x, y = NULL) .Call("dgeMatrix_crossprod", x, FALSE, PACKAGE = "Matrix"),
 	  valueClass = "dpoMatrix")
 
 setMethod("tcrossprod", signature(x = "dgeMatrix"),
-	  function(x) .Call("dgeMatrix_crossprod", x, TRUE),
+	  function(x) .Call("dgeMatrix_crossprod", x, TRUE, PACKAGE = "Matrix"),
 	  valueClass = "dpoMatrix")
 setMethod("tcrossprod", signature(x = "matrix"),
-	  function(x) .Call("dgeMatrix_crossprod", as(x, "dgeMatrix"), TRUE),
+	  function(x) .Call("dgeMatrix_crossprod", as(x, "dgeMatrix"), TRUE, PACKAGE = "Matrix"),
 	  valueClass = "dpoMatrix")
 setMethod("tcrossprod", signature(x = "numeric"),
 	  function(x) callGeneric(as.matrix(as.double(x))))
 
 
 setMethod("crossprod", signature(x = "dgeMatrix", y = "dgeMatrix"),
-	  function(x, y = NULL) .Call("dgeMatrix_dgeMatrix_crossprod", x, y),
+	  function(x, y = NULL) .Call("dgeMatrix_dgeMatrix_crossprod", x, y, PACKAGE = "Matrix"),
 	  valueClass = "dgeMatrix")
 
 setMethod("crossprod", signature(x = "dgeMatrix", y = "matrix"),
-	  function(x, y = NULL) .Call("dgeMatrix_matrix_crossprod", x, y),
+	  function(x, y = NULL) .Call("dgeMatrix_matrix_crossprod", x, y, PACKAGE = "Matrix"),
 	  valueClass = "dgeMatrix")
 setMethod("crossprod", signature(x = "dgeMatrix", y = "numeric"),
 	  function(x, y = NULL)
-	  .Call("dgeMatrix_matrix_crossprod", x, as.matrix(as.double(y))),
+	  .Call("dgeMatrix_matrix_crossprod", x, as.matrix(as.double(y)), PACKAGE = "Matrix"),
 	  valueClass = "dgeMatrix")
 setMethod("crossprod", signature(x = "matrix", y = "dgeMatrix"),
 	  function(x, y = NULL) callGeneric(as(x, "dgeMatrix"), y),
@@ -167,93 +167,94 @@ setMethod("crossprod", signature(x = "numeric", y = "dgeMatrix"),
 	  valueClass = "dgeMatrix")
 
 setMethod("%*%", signature(x = "dgeMatrix", y = "dgeMatrix"),
-	  function(x, y) .Call("dgeMatrix_matrix_mm", x, y, TRUE, FALSE),
+	  function(x, y) .Call("dgeMatrix_matrix_mm", x, y, TRUE, FALSE, PACKAGE = "Matrix"),
 	  valueClass = "dgeMatrix")
 
 ## dgeMatrix <-> matrix ("matrix" dispatches before "numeric" since R 2.1.0)
 setMethod("%*%", signature(x = "dgeMatrix", y = "matrix"),
 	  function(x, y) {
 	      storage.mode(y) <- "double"
-	      .Call("dgeMatrix_matrix_mm", x, y, FALSE, FALSE)
+	      .Call("dgeMatrix_matrix_mm", x, y, FALSE, FALSE, PACKAGE = "Matrix")
 	  }, valueClass = "dgeMatrix")
 
 
 setMethod("%*%", signature(x = "matrix", y = "dgeMatrix"),
 	  function(x, y) {
 	      storage.mode(x) <- "double"
-	      .Call("dgeMatrix_matrix_mm", y, x, FALSE, TRUE)
+	      .Call("dgeMatrix_matrix_mm", y, x, FALSE, TRUE, PACKAGE = "Matrix")
 	  }, valueClass = "dgeMatrix")
 
 ## dgeMatrix <-> numeric: conceptually dispatch to "matrix" one, but shortcut
 setMethod("%*%", signature(x = "dgeMatrix", y = "numeric"),
 	  function(x, y)
-	  .Call("dgeMatrix_matrix_mm", x, as.matrix(as.double(y)), FALSE, FALSE),
+	  .Call("dgeMatrix_matrix_mm", x, as.matrix(as.double(y)), FALSE, FALSE, PACKAGE = "Matrix"),
 	  valueClass = "dgeMatrix")
 setMethod("%*%", signature(x = "numeric", y = "dgeMatrix"),
 	  function(x, y)
-	  .Call("dgeMatrix_matrix_mm", y, rbind(as.double(x)), FALSE, TRUE),
+	  .Call("dgeMatrix_matrix_mm", y, rbind(as.double(x)), FALSE, TRUE, PACKAGE = "Matrix"),
 	  valueClass = "dgeMatrix")
 
 setMethod("diag", signature(x = "dgeMatrix"),
 	  function(x = 1, nrow, ncol = n)
-	  .Call("dgeMatrix_getDiag", x))
+	  .Call("dgeMatrix_getDiag", x, PACKAGE = "Matrix"))
 
 
 ## DB - I don't think this is a good idea without first checking symmetry
 #setMethod("chol", signature(x = "dgeMatrix", pivot = "ANY"), cholMat)
 
 setMethod("solve", signature(a = "dgeMatrix", b = "missing"),
-	  function(a, b, ...) .Call("dgeMatrix_solve", a),
+	  function(a, b, ...) .Call("dgeMatrix_solve", a, PACKAGE = "Matrix"),
 	  valueClass = "dgeMatrix")
 
 setMethod("solve", signature(a = "dgeMatrix", b = "dgeMatrix"),
-	  function(a, b, ...) .Call("dgeMatrix_matrix_solve", a, b, TRUE),
+	  function(a, b, ...) .Call("dgeMatrix_matrix_solve", a, b, TRUE, PACKAGE = "Matrix"),
 	  valueClass = "dgeMatrix")
 
 setMethod("solve", signature(a = "dgeMatrix", b = "matrix"),
 	  function(a, b, ...) {
 	      storage.mode(b) <- "double"
-	      .Call("dgeMatrix_matrix_solve", a, b, FALSE)
+	      .Call("dgeMatrix_matrix_solve", a, b, FALSE, PACKAGE = "Matrix")
 	  }, valueClass = "dgeMatrix")
 
 setMethod("solve", signature(a = "dgeMatrix", b = "numeric"),
 	  function(a, b, ...)
-	  .Call("dgeMatrix_matrix_solve", a, as.matrix(as.double(b)), FALSE))
+	  .Call("dgeMatrix_matrix_solve", a, as.matrix(as.double(b)), FALSE, PACKAGE = "Matrix"))
 
 setMethod("lu", signature(x = "dgeMatrix"),
-	  function(x, ...) .Call("dgeMatrix_LU", x), valueClass = "LU")
+	  function(x, ...) .Call("dgeMatrix_LU", x, PACKAGE = "Matrix"),
+          valueClass = "LU")
 
 setMethod("determinant", signature(x = "dgeMatrix", logarithm = "missing"),
 	  function(x, logarithm, ...)
-	  .Call("dgeMatrix_determinant", x, TRUE))
+	  .Call("dgeMatrix_determinant", x, TRUE, PACKAGE = "Matrix"))
 
 setMethod("determinant", signature(x = "dgeMatrix", logarithm = "logical"),
 	  function(x, logarithm, ...)
-	  .Call("dgeMatrix_determinant", x, logarithm))
+	  .Call("dgeMatrix_determinant", x, logarithm, PACKAGE = "Matrix"))
 
 
 setMethod("expm", signature(x = "dgeMatrix"),
-	  function(x) .Call("dgeMatrix_exp", x),
+	  function(x) .Call("dgeMatrix_exp", x, PACKAGE = "Matrix"),
 	  valueClass = "dgeMatrix")
 
 setMethod("colSums", signature(x = "dgeMatrix"),
 	  function(x, na.rm = FALSE, dims = 1)
-          .Call("dgeMatrix_colsums", x, na.rm, TRUE, FALSE),
+          .Call("dgeMatrix_colsums", x, na.rm, TRUE, FALSE, PACKAGE = "Matrix"),
 	  valueClass = "numeric")
 
 setMethod("colMeans", signature(x = "dgeMatrix"),
 	  function(x, na.rm = FALSE, dims = 1)
-          .Call("dgeMatrix_colsums", x, na.rm, TRUE, TRUE),
+          .Call("dgeMatrix_colsums", x, na.rm, TRUE, TRUE, PACKAGE = "Matrix"),
 	  valueClass = "numeric")
 
 setMethod("rowSums", signature(x = "dgeMatrix"),
 	  function(x, na.rm = FALSE, dims = 1)
-          .Call("dgeMatrix_colsums", x, na.rm, FALSE, FALSE),
+          .Call("dgeMatrix_colsums", x, na.rm, FALSE, FALSE, PACKAGE = "Matrix"),
 	  valueClass = "numeric")
 
 setMethod("rowMeans", signature(x = "dgeMatrix"),
 	  function(x, na.rm = FALSE, dims = 1)
-          .Call("dgeMatrix_colsums", x, na.rm, FALSE, TRUE),
+          .Call("dgeMatrix_colsums", x, na.rm, FALSE, TRUE, PACKAGE = "Matrix"),
 	  valueClass = "numeric")
 
 ### The following all serve for	 as.Matrix()
