@@ -36,7 +36,7 @@ SEXP Tsparse_to_Csparse(SEXP x)
     cholmod_triplet *chxt = as_cholmod_triplet(x);
     cholmod_sparse *chxs = cholmod_triplet_to_sparse(chxt, chxt->nnz, &c);
 
-    Free(chxt);
+    free(chxt);
     return chm_sparse_to_SEXP(chxs, 1);
 #else
     error("General conversion requires CHOLMOD");
